aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorrobot-contrib <robot-contrib@yandex-team.com>2023-12-18 01:34:49 +0300
committerrobot-contrib <robot-contrib@yandex-team.com>2023-12-18 03:21:34 +0300
commit1be7a368ccd0d328722cd7b30339cce09ad6ef2a (patch)
tree88a32db7fb0b65ab47d3107cf04bd130742d7eb3
parentb0192c91dee7364dc264ed5cd4e161089e7a1728 (diff)
downloadydb-1be7a368ccd0d328722cd7b30339cce09ad6ef2a.tar.gz
Update contrib/restricted/boost/optional to 1.84.0
-rw-r--r--contrib/restricted/boost/optional/include/boost/none_t.hpp8
-rw-r--r--contrib/restricted/boost/optional/include/boost/optional/detail/old_optional_implementation.hpp3
-rw-r--r--contrib/restricted/boost/optional/include/boost/optional/detail/optional_swap.hpp12
-rw-r--r--contrib/restricted/boost/optional/include/boost/optional/optional.hpp4
-rw-r--r--contrib/restricted/boost/optional/ya.make4
5 files changed, 20 insertions, 11 deletions
diff --git a/contrib/restricted/boost/optional/include/boost/none_t.hpp b/contrib/restricted/boost/optional/include/boost/none_t.hpp
index 6b3c8334dd..419a728660 100644
--- a/contrib/restricted/boost/optional/include/boost/none_t.hpp
+++ b/contrib/restricted/boost/optional/include/boost/none_t.hpp
@@ -14,6 +14,14 @@
#define BOOST_NONE_T_17SEP2003_HPP
#include <boost/config.hpp>
+#include <boost/config/pragma_message.hpp>
+
+#if defined (BOOST_NO_CXX11_RVALUE_REFERENCES) || defined(BOOST_NO_CXX11_VARIADIC_TEMPLATES) || defined(BOOST_NO_CXX11_REF_QUALIFIERS) \
+|| defined(BOOST_NO_CXX11_LAMBDAS) || defined(BOOST_NO_CXX11_DECLTYPE_N3276) || defined(BOOST_NO_CXX11_NOEXCEPT) || defined(BOOST_NO_CXX11_DELETED_FUNCTIONS) || defined(BOOST_NO_CXX11_DEFAULTED_FUNCTIONS) || defined(BOOST_NO_CXX11_DEFAULTED_MOVES) || defined(BOOST_NO_CXX11_EXPLICIT_CONVERSION_OPERATORS)
+
+BOOST_PRAGMA_MESSAGE("C++03 support is deprecated in Boost.Optional 1.83 and will be removed in Boost.Optional 1.86.")
+
+#endif
namespace boost {
diff --git a/contrib/restricted/boost/optional/include/boost/optional/detail/old_optional_implementation.hpp b/contrib/restricted/boost/optional/include/boost/optional/detail/old_optional_implementation.hpp
index 6d707fc07f..75d4bdcf1d 100644
--- a/contrib/restricted/boost/optional/include/boost/optional/detail/old_optional_implementation.hpp
+++ b/contrib/restricted/boost/optional/include/boost/optional/detail/old_optional_implementation.hpp
@@ -17,6 +17,7 @@
#include <boost/type_traits/is_reference.hpp>
#include <boost/type_traits/integral_constant.hpp>
#include <boost/type_traits/conditional.hpp>
+#include <boost/core/invoke_swap.hpp>
namespace boost {
@@ -894,7 +895,7 @@ class optional : public optional_detail::optional_base<T>
BOOST_NOEXCEPT_IF(::boost::is_nothrow_move_constructible<T>::value && ::boost::is_nothrow_move_assignable<T>::value)
{
// allow for Koenig lookup
- boost::swap(*this, arg);
+ boost::core::invoke_swap(*this, arg);
}
diff --git a/contrib/restricted/boost/optional/include/boost/optional/optional.hpp b/contrib/restricted/boost/optional/include/boost/optional/optional.hpp
index 56d50d7886..f5fdf992fc 100644
--- a/contrib/restricted/boost/optional/include/boost/optional/optional.hpp
+++ b/contrib/restricted/boost/optional/include/boost/optional/optional.hpp
@@ -30,7 +30,7 @@
#include <boost/core/addressof.hpp>
#include <boost/core/enable_if.hpp>
#include <boost/core/explicit_operator_bool.hpp>
-#include <boost/core/swap.hpp>
+#include <boost/core/invoke_swap.hpp>
#include <boost/optional/bad_optional_access.hpp>
#include <boost/static_assert.hpp>
#include <boost/throw_exception.hpp>
@@ -1260,7 +1260,7 @@ class optional
BOOST_NOEXCEPT_IF(::boost::is_nothrow_move_constructible<T>::value && ::boost::is_nothrow_move_assignable<T>::value)
{
// allow for Koenig lookup
- boost::swap(*this, arg);
+ boost::core::invoke_swap(*this, arg);
}
diff --git a/contrib/restricted/boost/optional/ya.make b/contrib/restricted/boost/optional/ya.make
index 5293a22613..e73f538e4d 100644
--- a/contrib/restricted/boost/optional/ya.make
+++ b/contrib/restricted/boost/optional/ya.make
@@ -6,9 +6,9 @@ LICENSE(BSL-1.0)
LICENSE_TEXTS(.yandex_meta/licenses.list.txt)
-VERSION(1.83.0)
+VERSION(1.84.0)
-ORIGINAL_SOURCE(https://github.com/boostorg/optional/archive/boost-1.83.0.tar.gz)
+ORIGINAL_SOURCE(https://github.com/boostorg/optional/archive/boost-1.84.0.tar.gz)
PEERDIR(
contrib/restricted/boost/assert
diff --git a/contrib/restricted/boost/optional/include/boost/optional/detail/optional_swap.hpp b/contrib/restricted/boost/optional/include/boost/optional/detail/optional_swap.hpp
index 2a7059e701..f4eceabb50 100644
--- a/contrib/restricted/boost/optional/include/boost/optional/detail/optional_swap.hpp
+++ b/contrib/restricted/boost/optional/include/boost/optional/detail/optional_swap.hpp
@@ -13,7 +13,7 @@
#ifndef BOOST_OPTIONAL_DETAIL_OPTIONAL_SWAP_AJK_28JAN2015_HPP
#define BOOST_OPTIONAL_DETAIL_OPTIONAL_SWAP_AJK_28JAN2015_HPP
-#include <boost/core/swap.hpp>
+#include <boost/core/invoke_swap.hpp>
#include <boost/optional/optional_fwd.hpp>
namespace boost {
@@ -39,8 +39,8 @@ struct swap_selector<true>
else if ( !hasY )
y.emplace();
- // Boost.Utility.Swap will take care of ADL and workarounds for broken compilers
- boost::swap(x.get(), y.get());
+ // Boost.Core.Swap will take care of ADL and workarounds for broken compilers
+ boost::core::invoke_swap(x.get(), y.get());
if( !hasX )
y = boost::none ;
@@ -64,13 +64,13 @@ struct swap_selector<false>
{
template <class T>
static void optional_swap ( optional<T>& x, optional<T>& y )
- //BOOST_NOEXCEPT_IF(::boost::is_nothrow_move_constructible<T>::value && BOOST_NOEXCEPT_EXPR(boost::swap(*x, *y)))
+ //BOOST_NOEXCEPT_IF(::boost::is_nothrow_move_constructible<T>::value && BOOST_NOEXCEPT_EXPR(boost::core::invoke_swap(*x, *y)))
{
if (x)
{
if (y)
{
- boost::swap(*x, *y);
+ boost::core::invoke_swap(*x, *y);
}
else
{
@@ -105,7 +105,7 @@ struct optional_swap_should_use_default_constructor : has_nothrow_default_constr
template <class T>
inline void swap ( optional<T>& x, optional<T>& y )
-//BOOST_NOEXCEPT_IF(::boost::is_nothrow_move_constructible<T>::value && BOOST_NOEXCEPT_EXPR(boost::swap(*x, *y)))
+//BOOST_NOEXCEPT_IF(::boost::is_nothrow_move_constructible<T>::value && BOOST_NOEXCEPT_EXPR(boost::core::invoke_swap(*x, *y)))
{
optional_detail::swap_selector<optional_swap_should_use_default_constructor<T>::value>::optional_swap(x, y);
}